*********************
``matplotlib.figure``
*********************

.. currentmodule:: matplotlib.figure

.. automodule:: matplotlib.figure
   :no-members:
   :no-inherited-members:

Classes
-------

.. autosummary::
   :toctree: _as_gen/
   :template: autosummary.rst
   :nosignatures:

   AxesStack
   Figure
   SubplotParams

Functions
---------

.. autosummary::
   :toctree: _as_gen/
   :template: autosummary.rst
   :nosignatures:

   figaspect
